"""
betamax_matchers
================

See https://betamax.readthedocs.org/ for documentation.

:copyright: (c) 2015 by Ian Cordasco
:license: Apache 2.0, see LICENSE for more details

"""

__author__ = 'Ian Stapleton Cordasco'
__copyright__ = 'Copyright 2019 Ian Stapleton Cordasco'
__license__ = 'Apache 2.0'
__title__ = 'betamax_serializers'
__version__ = '0.2.1'
__version_info__ = tuple(int(i) for i in __version__.split('.'))
